translate.misc.dictutils

Package translate :: Package misc :: Module dictutils |
[hide private]
[frames] | no frames]

# Module dictutils

source code

Implements a case-insensitive (on keys) dictionary and order-sensitive dictionary

Classes | [hide private]
| cidict
| ordereddict a dictionary which remembers its keys in the order in which they were given

Functions | [hide private]
generalupper(str) this uses the object's upper method - works with string and unicode | source code

Variables | [hide private]
| __package__ = `None` hash(x)